Authors
=======

* Philip Loche (`github <https://github.com/PicoCentauri>`_)
* Joao M. C. Teixeira (`webpage <https://bit.ly/joaomcteixeira>`_, `github <https://github.com/joaomcteixeira>`_)
* Oliver Beckstein (`webpage <https://becksteinlab.physics.asu.edu>`_, `github <https://github.com/orbeckst>`_)
* Lily Wang (`github <https://github.com/lilyminium>`_)